/*********************************************************************/
/*                                                                   */
/*    Product: RVS z/OS Kafka Connector (RzK)                        */
/*                                                                   */
/*       Type: C Program Source Code                                 */
/*                                                                   */
/*   Function: Produce and Consume a single message from a Kafka     */
/*                                                   cluster.        */
/*                                                                   */
/*      Notes: o Adapt the required RzK parms below to your needs.   */
/*                                                                   */
/*             o To keep the sample code short, there are only a     */
/*               few checks for return codes and error messages.     */
/*               Do NEVER do this in production code.                */
/*                                                                   */
/*                (C) Copyright rvs-Systems GmbH, Germany, 2021-2024 */
/*********************************************************************/
/* ****************************************************************************************************
* Change History
*
* 03Aug23 EWO initial Version
* 30Jan24 EWO V1.2.1, new expiration date
* 11Mar24 EWO V1.2.1_GSE, special Verision, special expiration
* *****************************************************************************************************/
#define RZK_VERSION "1.2.1_GSE"
#define RZK_COPYRIGHT "All rights reserved. Copyright 2021-2024 rvs-Systems GmbH, Ruesselsheim"



/* ***********************************************************************************************************************
*
* Function Prototypes.
*
************************************************************************************************************************ */
#define FCTPARM   0
#define FCTOPEN   1
#define FCTCONN   2 
#define FCTCLSE   3 
#define FCTPROD   4 
#define FCTCONS   5 
#define FCTDBUG   6 
#define FCTSYNC   7 
#define FCTAUTH   8 
#define FCTGERR   9 
#define FCTCLDB  10 
#define FCTTERM  11
#define FCTTIMO  12

#define RZKHANDLE int 


int       RZKFUNC(int iFuncCode, ...);         
/* The following functions can be used to directly or via the RZKFUNC call */
int       RZKOPEN();
int       RZKCONN(RZKHANDLE handle, char *Broker, int iBrokerLen, char *Topic, int iTopicLen);
int       RZKCLSE(RZKHANDLE handle);
int       RZKPROD(RZKHANDLE handle, char *MsgKey, int iMsgKeyLen, char *Msg, int iMsgLen, int iConv);
int       RZKCONS(RZKHANDLE handle, char *pszGroup, int iGroupLen, char *pOut, int *piLen, int iConv, int iTimeOut ); 
int       RZKDBUG(RZKHANDLE handle, int iDbgLvl);  
int       RZKSYNC(RZKHANDLE handle, int iSynchMode, unsigned int iSndWindSize, unsigned int iRecWindSize);  
int       RZKAUTH(RZKHANDLE handle, char *Username, int iUsernameLen, char *Password, int iPasswordLen);  
int		 RZKGERR(RZKHANDLE handle, char *pOut, int *pOLen);
int       RZKCLDB(RZKHANDLE handle, int iEnable);  
int       RZKTIMO( RZKHANDLE handle, int iTimeOutSeconds );
int       RZKTERM();
