/*********************************************************************/
/*                                                                   */
/*    Product: RVS z/OS Kafka Connector (RzK)                        */
/*                                                                   */
/*       Type: C Program Source Code                                 */
/*                                                                   */
/*   Function: Produce and Consume a single message from a Kafka     */
/*                                                   cluster.        */
/*                                                                   */
/*      Notes: o Adapt the required RzK parms below to your needs.   */
/*                                                                   */
/*             o To keep the sample code short, there are only a     */
/*               few checks for return codes and error messages.     */
/*               Do NEVER do this in production code.                */
/*                                                                   */
/*                (C) Copyright rvs-Systems GmbH, Germany, 2021-2024 */
/*********************************************************************/
/* **** Change History ************************************************
* 10Aug23 EWO * initial version
* ********************************************************************/

#include <stdio.h>
#ifndef WIN32
#include <string.h>
#endif

#include "rzk.h"


int main( int argc, char *argv[] )
{
   int iRC;

   printf( "\nRzK, the rvs-Systems zKafka Connector\n\n" );
   printf( "CLI Sample Program Version " RZK_VERSION " Build " __DATE__ " " __TIME__ "\n" );
   printf( RZK_COPYRIGHT "\n\n" );

  char *pszHostName = argv[1];
  char *pszTopic = argv[2];
  char *pszMsg = argv[3];


   printf( "\n+++++++++ Connecting to bootstrap server %s\n", pszHostName );
   printf( "            Topic  = %s\n", pszTopic );
   printf( "            Msg    = %s\n", pszMsg );
   printf( "\n" );

   int handle = RZKFUNC( FCTOPEN );
   do {
      if ( handle < 0 ) break;
      RZKFUNC( FCTDBUG, handle, 0 );

      iRC = RZKFUNC( FCTCONN, handle, pszHostName, strlen( pszHostName ), pszTopic, strlen( pszTopic ) );
      if ( iRC ) break;

      iRC = RZKFUNC( FCTPROD, handle, "", 0, pszMsg, strlen( pszMsg ), 0 );
      if ( iRC ) break;

      char szT[1024];
      int iLen = sizeof( szT );
      iRC = RZKFUNC( FCTCONS, handle, "xxx", 3, szT, &iLen, 0, 5 );
      if ( iRC ) break;

      printf( "RzK CLI Sample Received Message from Kafka (len=%d): %s\n", iLen, szT );
   } while ( 0 );
   RZKCLSE( handle );

   return 0;
}
