/*********************************************************************/
/*                                                                   */
/*    Product: RVS z/OS Kafka Connector (RzK)                        */
/*                                                                   */
/*       Type: C Program Source Code                                 */
/*                                                                   */
/*   Function: Produce and Consume a single message from a Kafka     */
/*                                                   cluster.        */
/*                                                                   */
/*      Notes: o Adapt the required RzK parms below to your needs.   */
/*                                                                   */
/*             o To keep the sample code short, there are only a     */
/*               few checks for return codes and error messages.     */
/*               Do NEVER do this in production code.                */
/*                                                                   */
/*                (C) Copyright rvs-Systems GmbH, Germany, 2021-2024 */
/*********************************************************************/
/* **** Change History ************************************************
* 10Aug23 EWO * initial version
* ********************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "rzk.h"

#ifdef WIN32
#define mysleep(a) Sleep(a)
#else
#define mysleep(a) usleep(a*1000)
#endif


int main( int argc, char *argv[] )
{
   int iRC;

   printf( "\nRzK, the rvs-Systems zKafka Connector\n\n" );
   printf( "Test Program Version " RZK_VERSION " Build " __DATE__ " " __TIME__ "\n" );
   printf( RZK_COPYRIGHT "\n\n" );

  char *pszHostName = "ewu-kafka02.rvs-technet.de:9090";
  char *pszTopic = "ewo35d";
  char *pszMsg = "Test_Message";
  int iTimeout = atoi( argv[1] );
  int iDelay = atoi( argv[2] );

   printf( "\n+++++++++ Connecting to bootstrap server %s\n", pszHostName );
   printf( "            Topic  = %s\n", pszTopic );
   printf( "            Msg    = %s\n", pszMsg );
   printf( "            CoordinatorTimeout = %d\n", iTimeout );
   printf( "            Delay between Consumes = %d\n", iDelay );
   printf( "\n" );

   int handle = RZKFUNC( FCTOPEN );
   do {
      if ( handle < 0 ) break;
      RZKFUNC( FCTDBUG, handle, 1 );

      iRC = RZKFUNC( FCTCONN, handle, pszHostName, strlen( pszHostName ), pszTopic, strlen( pszTopic ) );
      if ( iRC ) break;

      iRC = RZKFUNC( FCTTIMO, handle, iTimeout );
      if ( iRC ) break;

      int i = 1;
      do {
         char szT[1024];
         int iLen = sizeof( szT );
         iRC = RZKCONS( handle, "xxx", 3, szT, &iLen, 1, 60 );
         if ( iRC ) break;

         printf( "RzK Test Received Message %u of %u from Kafka (len=%d): %s\n", i, 100, iLen, szT );
         if ( iDelay )  mysleep( iDelay*1000 );

      } while ( i++ < 100 );
   } while ( 0 );
   RZKCLSE( handle );

   return 0;
}
